pub struct IncompleteAt {
pub address: Address,
pub required_for_witness: bool,
}Expand description
A data structure describing the nature of a Node::Nil node in the tree that was introduced
as the consequence of an insertion.
Fields
address: AddressThe address of the empty node.
required_for_witness: boolA flag identifying whether or not the missing node is required in order to construct a
witness for a node with MARKED retention.